@@ -1,7 +1,7 @@
-from PyPDF3 import PdfFileReader
+from pypdf import PdfReader
 
 
-def pypdf3_reader(pdf, decrypt=None):
+def pypdf_reader(pdf, decrypt=None) -> PdfReader:
     """
     Retrieve a PdfFileReader object that has been decrypted if a password is specified.
 
@@ -10,8 +10,8 @@ def pypdf3_reader(pdf, decrypt=None):
     :return: PdfFileReader object
     """
     if decrypt:
-        reader = PdfFileReader(pdf)
+        reader = PdfReader(pdf)
         reader.decrypt(decrypt)
         return reader
     else:
-        return PdfFileReader(pdf)
+        return PdfReader(pdf)
